@@ -1,6 +1,6 @@
 #! /usr/lib/veetest/veetest -r
-(revision "A.00.00")
-(date "Wed 10/Apr/1991")
+(revision "A.00.01")
+(date "Tue 10/Mar/1992")
 (component 0 "Context"
  (name "Mixer Example")
  (interface
@@ -10,6 +10,18 @@
   (locked no)
   (component 0 "Context"
    (name "Create Mapping Array")
+   (description 10 4
+    Certain array types have mappings: functions,
+    spectra, and waveforms.  This library object 
+    creates an array which contains the "x" values 
+    for the "y" values in the mapped array.
+    
+    For a spectrum, the array contains the frequencies
+    of the values in the spectrum.
+    
+    For a waveform, the array contains time values for
+    the points in the waveform.
+   )
    (interface
     (sequence in)
     (sequence out)
@@ -361,7 +373,7 @@
       (icon
        (origin 621 608)
        (extent 118 64)
-       (iconImage build.icon)
+       (iconImage "build.icon")
       )
       (detail
        (extent 0 83)
@@ -391,18 +403,6 @@
     )
    )
    (views
-    (description 10 5
-     Certain array types have mappings: functions,
-     spectra, and waveforms.  This library object 
-     creates an array which contains the "x" values 
-     for the "y" values in the mapped array.
-     
-     For a spectrum, the array contains the frequencies
-     of the values in the spectrum.
-     
-     For a waveform, the array contains time values for
-     the points in the waveform.
-    )
     (icon
      (origin 135 598)
      (extent 190 25)
@@ -703,7 +703,7 @@
    )
    (views
     (icon
-     (iconImage display.icon)
+     (iconImage "display.icon")
     )
     (detail
      (origin 464 230)
@@ -714,20 +714,20 @@
      (scale 0
       (name "Mag")
       (domainName "Freq")
-      (color 0x909090)
+      (pen 9)
       (show 1)
       (range 0 4000 4 linear)
      )
      (domain 495000 505000 4 linear)
      (trace 0 onScale 0
       (name "unfiltered")
-      (color 0xffdd00)
+      (pen 4)
       (lineType 1)
       (pointType 0)
      )
      (trace 1 onScale 0
       (name "filtered")
-      (color 0xccff)
+      (pen 7)
       (lineType 1)
       (pointType 0)
      )
@@ -862,50 +862,7 @@
     (active detail)
    )
   )
-  (component 11 "Formula"
-   (name "band pass")
-   (interface
-    (sequence in)
-    (sequence out)
-    (input 1
-     (type data)
-     (name "w")
-     (optional yes)
-    )
-    (input 2
-     (type data)
-     (name "Q")
-     (optional yes)
-    )
-    (input 3
-     (type data)
-     (name "fo")
-     (optional yes)
-    )
-    (output 1
-     (type data)
-     (name " ")
-     (lock name constraints)
-    )
-   )
-   (implementation
-    (component isLocked no)
-    (component expr 1 "w*(fo/Q)/((w^2-fo^2)+j(w*fo/Q))")
-   )
-   (views
-    (icon
-     (origin 243 703)
-     (extent 95 34)
-    )
-    (detail
-     (origin 132 606)
-     (extent 326 128)
-    )
-    (terminals on)
-    (active icon)
-   )
-  )
-  (component 12 "Note"
+  (component 11 "Note"
    (name "Overview of Mixer Example")
    (interface
    )
@@ -972,26 +929,69 @@
     (active detail)
    )
   )
+  (component 12 "Formula"
+   (name "band pass")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "f")
+     (optional yes)
+    )
+    (input 2
+     (type data)
+     (name "Q")
+     (optional yes)
+    )
+    (input 3
+     (type data)
+     (name "fo")
+     (optional yes)
+    )
+    (output 1
+     (type data)
+     (name " ")
+     (lock name constraints)
+    )
+   )
+   (implementation
+    (component isLocked no)
+    (component expr 1 "j(f*(fo/Q))/((fo^2-f^2)+j(f*fo/Q))")
+   )
+   (views
+    (icon
+     (origin 253 703)
+     (extent 95 34)
+    )
+    (detail
+     (origin 85 356)
+     (extent 340 128)
+    )
+    (terminals on)
+    (active icon)
+   )
+  )
   (configuration
    (connect D4:1 D0:1)
    (connect D9:1 D3:1)
    (connect D8:1 D3:2)
    (connect D3:1 D4:1)
    (connect D4:1 D5:1)
-   (connect D11:1 D5:2)
+   (connect D12:1 D5:2)
    (connect D3:1 D6:1)
    (connect D5:1 D6:2)
    (connect D9:0 D8:0)
    (connect D2:0 D9:0)
-   (connect D0:1 D11:1)
-   (connect D1:1 D11:2)
-   (connect D10:1 D11:3)
+   (connect D0:1 D12:1)
+   (connect D1:1 D12:2)
+   (connect D10:1 D12:3)
   )
  )
  (views
   (detail
    (origin 0 67)
-   (extent 980 636)
+   (extent 780 513)
    (configuration
     (connect D4:1 D0:1
      (Point 316 540)
@@ -1021,10 +1021,10 @@
      (Point 330 580)
      (Point 377 580)
     )
-    (connect D11:1 D5:2
-     (Point 340 720)
-     (Point 360 720)
-     (Point 360 600)
+    (connect D12:1 D5:2
+     (Point 350 720)
+     (Point 370 720)
+     (Point 370 600)
      (Point 377 600)
     )
     (connect D3:1 D6:1
@@ -1049,25 +1049,23 @@
      (Point 70 472)
      (Point 70 485)
     )
-    (connect D0:1 D11:1
+    (connect D0:1 D12:1
      (Point 327 610)
      (Point 340 610)
      (Point 340 640)
-     (Point 220 640)
-     (Point 220 710)
-     (Point 240 710)
+     (Point 230 640)
+     (Point 230 710)
+     (Point 250 710)
     )
-    (connect D1:1 D11:2
+    (connect D1:1 D12:2
      (Point 105 650)
-     (Point 210 650)
-     (Point 210 720)
-     (Point 240 720)
+     (Point 220 650)
+     (Point 220 720)
+     (Point 250 720)
     )
-    (connect D10:1 D11:3
+    (connect D10:1 D12:3
      (Point 204 730)
-     (Point 222 730)
-     (Point 222 730)
-     (Point 240 730)
+     (Point 250 730)
     )
    )
   )
